# pyqt-ext
Collection of PyQt/PySide widgets/tools.

In addition to being useful out-of-the-box, you may find these tools to be helpful templates for rolling your own custom widgets.

- `tree/`
    - [Tree model/view interface](docs/AbstractTree.md)
    - [(key, value) tree model/view](docs/KeyValueTree.md)
- `utils/`
    - [Color utils](docs/ColorUtils.md)
- `widgets/`
    - [Color selection button](docs/ColorButton.md)
    - [Multi-value spinbox](docs/MultiValueSpinBox.md)

# Install
Should work with PySide6, PyQt6, or PyQt5.
```shell
pip install PySide6 pyqt-ext
```
